@@ -1,4 +1,6 @@
+import logging
 import smtplib
+import ssl
 
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
@@ -12,14 +14,17 @@ class Messenger(object):
         message['To'] = receiver_address
         message['Subject'] = subject
         message.attach(MIMEText(mail_content, 'plain'))
-        session = smtplib.SMTP(config.smtp_server_host,
-                               config.smtp_server_port)
+        session = smtplib.SMTP_SSL(config.smtp_server_host,
+                                   config.smtp_server_port)
         if config.smtp_tls_enabled:
             session.starttls()
         session.login(config.sender_address, config.sender_passwd)
-        session.sendmail(config.sender_address,
-                         receiver_address, message.as_string())
+        recipients = receiver_address.split(",")
+        logging.info("sending an email to {}".format(str(recipients)))
+        result = session.sendmail(config.sender_address,
+                                  recipients, message.as_string())
         session.quit()
+        logging.info("smtp server returns {}".format(str(result)))
 
     def send_heartbeat(self, mail_content, config):
         self.send_email(config.heartbeat_receiver_addresses,
